summaryrefslogtreecommitdiffstats
path: root/os-plugins/plugins/vmware
diff options
context:
space:
mode:
authorOliver Tappe2008-04-06 15:40:09 +0200
committerOliver Tappe2008-04-06 15:40:09 +0200
commit5a8c8a1638eea2ff6897046fcbc94bb42ccbe94d (patch)
tree036281d5a9b6d847c4bfc92f3c52f96a6ada2df0 /os-plugins/plugins/vmware
parent* Instead of passing all known attributes of the current system into each plu... (diff)
downloadcore-5a8c8a1638eea2ff6897046fcbc94bb42ccbe94d.tar.gz
core-5a8c8a1638eea2ff6897046fcbc94bb42ccbe94d.tar.xz
core-5a8c8a1638eea2ff6897046fcbc94bb42ccbe94d.zip
* made names of distro module consistent across OpenSLX - now the always start with
a capital letter followed by all lowercase (Debian, Fedora, Gentoo, Suse, Ubuntu) * refactored loading of distro modules into a separate function (loadDistroModule() in Basics.pm) * finished support to logging to a file in syslog plugin * worked at desktop plugin (still not working, though) git-svn-id: http://svn.openslx.org/svn/openslx/openslx/trunk@1721 95ad53e4-c205-0410-b2fa-d234c58c8868
Diffstat (limited to 'os-plugins/plugins/vmware')
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm7
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm (renamed from os-plugins/plugins/vmware/OpenSLX/Distro/ubuntu.pm)11
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/Fedora.pm (renamed from os-plugins/plugins/vmware/OpenSLX/Distro/debian.pm)15
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/Gentoo.pm (renamed from os-plugins/plugins/vmware/OpenSLX/Distro/gentoo.pm)9
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/Suse.pm (renamed from os-plugins/plugins/vmware/OpenSLX/Distro/suse.pm)9
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/Ubuntu.pm23
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/fedora.pm48
7 files changed, 48 insertions, 74 deletions
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm
index 317bd13f..3c128f14 100644
--- a/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm
+++ b/os-plugins/plugins/vmware/OpenSLX/Distro/Base.pm
@@ -8,11 +8,10 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# base.pm
-# - provides empty base of the OpenSLX OSPlugin Distro API for the vmware
-# plugin.
+# vmware/OpenSLX/Distro/Base.pm
+# - provides base implementation of the Distro API for the vmware plugin.
# -----------------------------------------------------------------------------
-package OpenSLX::Distro::Base;
+package vmware::OpenSLX::Distro::Base;
use strict;
use warnings;
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/Ubuntu.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/Ubuntu.pm
new file mode 100644
index 00000000..02b44b5c
--- /dev/null
+++ b/os-plugins/plugins/vmware/OpenSLX/Distro/Ubuntu.pm
@@ -0,0 +1,23 @@
+# Copyright (c) 2006, 2007 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# vmware/OpenSLX/Distro/Ubuntu.pm
+# - provides Ubuntu-specific overrides of the Distro API for the vmware
+# plugin.
+# -----------------------------------------------------------------------------
+package vmware::OpenSLX::Distro::Ubuntu;
+
+use strict;
+use warnings;
+
+# inherit everything from Debian (as Ubuntu is based on it anyway)
+use base qw(vmware::OpenSLX::Distro::Debian);
+
+1; \ No newline at end of file
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/fedora.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/fedora.pm
deleted file mode 100644
index 0bc9ebdc..00000000
--- a/os-plugins/plugins/vmware/OpenSLX/Distro/fedora.pm
+++ /dev/null
@@ -1,48 +0,0 @@
-# Copyright (c) 2006, 2007 - OpenSLX GmbH
-#
-# This program is free software distributed under the GPL version 2.
-# See http://openslx.org/COPYING
-#
-# If you have any feedback please consult http://openslx.org/feedback and
-# send your suggestions, praise, or complaints to feedback@openslx.org
-#
-# General information about OpenSLX can be found at http://openslx.org/
-# -----------------------------------------------------------------------------
-# Fedora.pm
-# - provides Fedora-specific overrides of the OpenSLX OSSetup API.
-# -----------------------------------------------------------------------------
-package OpenSLX::OSSetup::Distro::Fedora;
-
-use strict;
-use warnings;
-
-use base qw(OpenSLX::OSSetup::Distro::Base);
-
-use OpenSLX::Basics;
-
-################################################################################
-### interface methods
-################################################################################
-sub new
-{
- my $class = shift;
- my $self = {};
- return bless $self, $class;
-}
-
-sub initialize
-{
- my $self = shift;
- my $engine = shift;
-
- $self->SUPER::initialize($engine);
- $self->{'packager-type'} = 'rpm';
- $self->{'meta-packager-type'} = $ENV{SLX_META_PACKAGER} || 'yum';
- $self->{'stage1c-faked-files'} = [
- '/etc/fstab',
- '/etc/mtab',
- ];
- return;
-}
-
-1; \ No newline at end of file
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/ubuntu.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm
index 7346918c..e8f40c16 100644
--- a/os-plugins/plugins/vmware/OpenSLX/Distro/ubuntu.pm
+++ b/os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm
@@ -1,4 +1,4 @@
-# Copyright (c) 2006, 2007 - OpenSLX GmbH
+# Copyright (c) 2008 - OpenSLX GmbH
#
# This program is free software distributed under the GPL version 2.
# See http://openslx.org/COPYING
@@ -8,15 +8,16 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# Ubuntu.pm
# - provides Ubuntu-specific overrides of the OpenSLX OSSetup API.
# -----------------------------------------------------------------------------
-package OpenSLX::Distro::ubuntu;
+package vmware::OpenSLX::Distro::Debian;
use strict;
use warnings;
-use base qw(OpenSLX::Distro::Base);
+use base qw(vmware::OpenSLX::Distro::Base);
use OpenSLX::Basics;
use OpenSLX::Utils;
@@ -8,15 +8,16 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# Ubuntu.pm
-# - provides Ubuntu-specific overrides of the OpenSLX OSSetup API.
+# vmware/OpenSLX/Distro/debian.pm
+# - provides Debian-specific overrides of the Distro API for the vmware
+# plugin.
# -----------------------------------------------------------------------------
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/debian.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/Fedora.pm
index 32a3d4bd..1a68a286 100644
--- a/os-plugins/plugins/vmware/OpenSLX/Distro/debian.pm
+++ b/os-plugins/plugins/vmware/OpenSLX/Distro/Fedora.pm
@@ -1,4 +1,4 @@
-# Copyright (c) 2008 - OpenSLX GmbH
+# Copyright (c) 2006, 2007 - OpenSLX GmbH
#
# This program is free software distributed under the GPL version 2.
# See http://openslx.org/COPYING
@@ -8,24 +8,23 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# debian.pm
# - provides Debian-specific overrides of the OpenSLX Distro API for the
# desktop plugin.
# -----------------------------------------------------------------------------
-package OpenSLX::Distro::debian;
+package vmware::OpenSLX::Distro::Fedora;
use strict;
use warnings;
-use base qw(OpenSLX::Distro::Base);
+use base qw(vmware::OpenSLX::Distro::Base);
use OpenSLX::Basics;
-use OpenSLX::Utils;
################################################################################
### interface methods
################################################################################
-### Erbe von Ubuntu!
+# TODO: implement!
1; \ No newline at end of file
@@ -8,24 +8,23 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# debian.pm
-# - provides Debian-specific overrides of the OpenSLX Distro API for the
-# desktop plugin.
+# vmware/OpenSLX/Distro/Fedora.pm
+# - provides Fedora-specific overrides of the Distro API for the vmware
+# plugin.
# -----------------------------------------------------------------------------
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/gentoo.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/Gentoo.pm
index 924c2fc2..594a55cd 100644
--- a/os-plugins/plugins/vmware/OpenSLX/Distro/gentoo.pm
+++ b/os-plugins/plugins/vmware/OpenSLX/Distro/Gentoo.pm
@@ -8,15 +8,16 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# SUSE.pm
# - provides SUSE-specific overrides of the OpenSLX OSSetup API.
# -----------------------------------------------------------------------------
-package OpenSLX::OSSetup::Distro::Gentoo;
+package vmware::OpenSLX::Distro::Gentoo;
use strict;
use warnings;
-use base qw(OpenSLX::OSSetup::Distro::Base);
+use base qw(vmware::OpenSLX::Distro::Base);
use OpenSLX::Basics;
@@ -8,15 +8,16 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# SUSE.pm
-# - provides SUSE-specific overrides of the OpenSLX OSSetup API.
+# vmware/OpenSLX/Distro/Gentoo.pm
+# - provides Gentoo-specific overrides of the Distro API for the vmware
+# plugin.
# -----------------------------------------------------------------------------
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/suse.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/Suse.pm
index b3a39df5..9c380cb6 100644
--- a/os-plugins/plugins/vmware/OpenSLX/Distro/suse.pm
+++ b/os-plugins/plugins/vmware/OpenSLX/Distro/Suse.pm
@@ -8,16 +8,15 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# SUSE.pm
# - provides SUSE-specific overrides of the OpenSLX Distro API for the desktop
# plugin.
# -----------------------------------------------------------------------------
-package OpenSLX::Distro::suse;
+package vmware::OpenSLX::Distro::Suse;
use strict;
use warnings;
-use base qw(OpenSLX::Distro::Base);
+use base qw(vmware::OpenSLX::Distro::Base);
use OpenSLX::Basics;
use OpenSLX::Utils;
@@ -8,16 +8,15 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# SUSE.pm
-# - provides SUSE-specific overrides of the OpenSLX Distro API for the desktop
-# plugin.
+# vmware/OpenSLX/Distro/Suse.pm
+# - provides SUSE-specific overrides of the Distro API for the vmware plugin.
# -----------------------------------------------------------------------------